@@ -1,5 +1,4 @@
 use fvm_shared::clock::ChainEpoch;
-use fvm_shared::crypto::randomness::DomainSeparationTag;
 use fvm_shared::randomness::Randomness;
 
 use crate::{sys, SyscallResult};
@@ -9,17 +8,12 @@ use crate::{sys, SyscallResult};
 /// If this syscall succeeds, exactly 32 bytes will be written starting at the
 /// supplied offset.
 pub fn get_chain_randomness(
-    dst: DomainSeparationTag,
+    dst: i64,
     round: ChainEpoch,
     entropy: &[u8],
 ) -> SyscallResult<Randomness> {
     let ret = unsafe {
-        sys::rand::get_chain_randomness(
-            dst as i64,
-            round as i64,
-            entropy.as_ptr(),
-            entropy.len() as u32,
-        )?
+        sys::rand::get_chain_randomness(dst, round as i64, entropy.as_ptr(), entropy.len() as u32)?
     };
     Ok(Randomness(ret.to_vec()))
 }
@@ -29,17 +23,12 @@ pub fn get_chain_randomness(
 /// If this syscall succeeds, exactly 32 bytes will be written starting at the
 /// supplied offset.
 pub fn get_beacon_randomness(
-    dst: DomainSeparationTag,
+    dst: i64,
     round: ChainEpoch,
     entropy: &[u8],
 ) -> SyscallResult<Randomness> {
     let ret = unsafe {
-        sys::rand::get_beacon_randomness(
-            dst as i64,
-            round as i64,
-            entropy.as_ptr(),
-            entropy.len() as u32,
-        )?
+        sys::rand::get_beacon_randomness(dst, round as i64, entropy.as_ptr(), entropy.len() as u32)?
     };
     Ok(Randomness(ret.to_vec()))
 }
